Type: Package
Package: bbnet
Title: Create Simple Predictive Models on Bayesian Belief Networks
Version: 1.0.1
Authors@R: c(
    person("Victoria", "Dominguez Almela", , "vda1r22@soton.ac.uk", role = c("cre","aut"),
           comment = c(ORCID = "0000-0003-4877-5967")),
           person("Richard", "Stafford", , "rstafford@bournemouth.ac.uk", role = c("cph", "aut"),
           comment = c(ORCID = "0000-0002-1964-5787"))
    )
Maintainer: Victoria Dominguez Almela <vda1r22@soton.ac.uk>
Description: A system to build, visualise and evaluate Bayesian belief networks. The methods are described in Stafford et al. (2015) <doi:10.12688/f1000research.5981.1>.
License: GPL (>= 2)
URL: https://github.com/vda1r22/bbnet
BugReports: https://github.com/vda1r22/bbnet/issues
Depends: R (>= 3.5.0), dplyr, ggplot2, grid, igraph, tibble
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.1
Suggests: knitr, rmarkdown, testthat
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-05-18 10:07:35 UTC; vda1r22
Author: Victoria Dominguez Almela [cre, aut]
    (<https://orcid.org/0000-0003-4877-5967>),
  Richard Stafford [cph, aut] (<https://orcid.org/0000-0002-1964-5787>)
Repository: CRAN
Date/Publication: 2024-05-18 13:20:03 UTC
Built: R 4.4.0; ; 2024-05-21 22:11:04 UTC; unix
